@@ -6,7 +6,7 @@
 
 '''A simple Twitter client made with pyqt4'''
 
-__version__ = '0.1.14'
+__version__ = '0.1.15'
 
 #TODOS :
 #* Fix Identi.ca oauth bug
@@ -339,13 +339,13 @@ class KhweetAction(QMainWindow):
             self.close()
 
         if hasattr(status,'user'):
-            if hasattr(status.user,'status.user.screen_name'):            
+            if hasattr(status.user,'status.user.name'):            
                 _screen_name = status.user.name + ' (' + status.user.screen_name+')'
             else:
-                _screen_name = status.user.name
+                _screen_name = status.user.screen_name
             icon_path = os.path.basename(status.user.profile_image_url.replace('/' , '_'))
         else:
-            _screen_name = sender_screen_name
+            _screen_name = status.sender_screen_name
             icon_path = None
         _text = status.text
         
